# Exceptions
#### nocton.generics.exeptions

Nocton possui algumas APIExceptions úteis.

### **BAD_REQUEST(message)**

Retorna um bad_request (400) com a mensagem passada como parâmetro.

### **NOT_FOUND(message)**

Retorna um not_found (404) com a mensagem passada como parâmetro.